@@ -3,16 +3,16 @@ from numpy import asarray, array, ndarray, vstack, newaxis, nonzero, concatenate
 from matplotlib.path import Path
 
 
-def add_property(d, prop, name):
+def add_property(d, prop, name, **kwargs):
 
     if prop is not None:
-        p = check_property(prop, name)
+        p = check_property(prop, name, **kwargs)
         d[name] = p
 
     return d
 
 
-def check_property(prop, name):
+def check_property(prop, name, **kwargs):
     """
     Check and parse a property with either a specific checking function
     or a generic parser
@@ -23,16 +23,31 @@ def check_property(prop, name):
         'alpha': check_alpha,
         'size': check_size,
         'index': check_index,
+        'coordinates': check_coordinates,
     }
 
     if name in checkers:
-        return checkers[name](prop)
+        return checkers[name](prop, **kwargs)
     elif isinstance(prop, list) or isinstance(prop, ndarray) or isscalar(prop):
         return check_1d(prop, name)
     else:
         return prop
 
 
+def check_coordinates(co, xy=None):
+    """
+    Check and parse coordinates as either a single coordinate list [[r,c],[r,c]] or a
+    list of coordinates for multiple regions [[[r0,c0],[r0,c0]], [[r1,c1],[r1,c1]]]
+    """
+    if isinstance(co, ndarray):
+        co = co.tolist()
+    if not (isinstance(co[0][0], list) or isinstance(co[0][0], tuple)):
+        co = [co]
+    if xy is not True:
+        co = map(lambda p: asarray(p)[:, ::-1].tolist(), co)
+    return co
+
+
 def check_color(c):
     """
     Check and parse color specs as either a single [r,g,b] or a list of
@@ -55,10 +70,10 @@ def check_colormap(cmap):
     """
     Check if cmap is one of the colorbrewer maps
     """
-    names = {'BrBG', 'PiYG', 'PRGn', 'PuOr', 'RdBu', 'RdGy', 'RdYlBu', 'RdYlGn', 'Spectral', 'Blues', 'BuGn', 'BuPu',
+    names = set(['BrBG', 'PiYG', 'PRGn', 'PuOr', 'RdBu', 'RdGy', 'RdYlBu', 'RdYlGn', 'Spectral', 'Blues', 'BuGn', 'BuPu',
              'GnBu', 'Greens', 'Greys', 'Oranges', 'OrRd', 'PuBu', 'PuBuGn', 'PuRd', 'Purples', 'RdPu', 'Reds',
              'YlGn', 'YlGnBu', 'YlOrBr', 'YlOrRd', 'Accent', 'Dark2',
-             'Paired', 'Pastel1', 'Pastel2', 'Set1', 'Set2', 'Set3'}
+             'Paired', 'Pastel1', 'Pastel2', 'Set1', 'Set2', 'Set3'])
     if cmap not in names:
         raise Exception("Invalid cmap '%s',  must be one of %s" % (cmap, names))
 
@@ -256,7 +271,7 @@ def polygon_to_points(coords, z=None):
 
     points = path.contains_points(grid_flat).reshape(grid[0].shape).astype('int')
     points = where(points)
-    points = vstack([points[0], points[1]]).T + bmin[-1::-1]
+    points = (vstack([points[0], points[1]]).T + bmin[-1::-1]).tolist()
     if z is not None:
         points = map(lambda p: [p[0], p[1], z], points)
 
